pub struct NormalMapOptions {
pub format: NormalMapFormat,
pub invert_y: bool,
pub tangent_space: bool,
pub flip_y: bool,
pub flip_x: bool,
pub encoding: NormalChannelEncoding,
}Expand description
Options for normal map extraction
Fields
format: NormalMapFormatOutput format
invert_y: boolWhether to invert Y axis
tangent_space: boolWhether to use tangent space normals (vs object space)
flip_y: boolWhether to flip the Y axis in the image
flip_x: boolWhether to flip the X axis in the image
encoding: NormalChannelEncodingNormal map channel encoding mode